@@ -19,6 +19,7 @@ class DataSourceType(str, Enum):
     CONFLUENCE = "knowledge_base_confluence"
     JIRA = "knowledge_base_jira"
     FILE = "knowledge_base_file"
+    XRAY = "knowledge_base_xray"
     GOOGLE = "llm_routing_google"
     PROVIDER = "provider"
     SUMMARY = "summary"
@@ -217,10 +218,6 @@ class AzureDevOpsWikiDataSourceRequest(BaseDataSourceRequest, AzureDevOpsWiki):
     def __init__(self, **data):
         super().__init__(type=DataSourceType.AZURE_DEVOPS_WIKI, **data)
 
-    @classmethod
-    def required_fields(cls) -> List[str]:
-        return ["wiki_query"]
-
 
 class BaseUpdateDataSourceRequest(BaseDataSourceRequest):
     """Mixin update-specific reindex fields"""
